/**
 * The library is subject to the Mozilla Public License Version 1.1.
 * Alternatively, the library may be used under the terms of either
 * the GNU General Public License Version 2 or later,
 * or the GNU Lesser General Public License 2.1 or later. 
 */
package com.skyarts.android.universalchardetect;

import org.mozilla.universalchardet.UniversalDetector;

import com.skyarts.android.universalchardetect.IUniversalCharDetectService;

import android.app.Service;
import android.content.Intent;
import android.os.IBinder;
import android.os.RemoteException;

/**
 * An implementation class of IUniversalCharDetectService.
 * 
 * @author SkyArts.com
 * @version 1.0
 */
public class UniversalCharDetectService extends Service {
    /** UniversalCharDetectService */
    private IUniversalCharDetectService.Stub iUCDService = new IUniversalCharDetectService.Stub() {
        /**
         * Return a encoding name.
         *
         * @param buf A value to detect.
         * @param offset The index of the first byte.
         * @param length The number of bytes.
         * @return Return a encoding name. Return null when cannot detect it.
         * @see com.skyarts.android.universalchardetect.IUniversalCharDetectService#getDetectedCharset(byte[], int, int)
         */
        public String getDetectedCharset(final byte[] buf, int offset, int length) throws RemoteException {
            UniversalDetector detector = new UniversalDetector(null);
            detector.handleData(buf, offset, length);
            detector.dataEnd();

            String encoding = detector.getDetectedCharset();
            detector.reset();
            return encoding;
        }
    };

    /*
     * (non-Javadoc)
     * 
     * @see android.app.Service#onBind(android.content.Intent)
     */
    @Override
    public IBinder onBind(Intent intent) {
        if (IUniversalCharDetectService.class.getName().equals(intent.getAction())) {
            return iUCDService;
        }
        return null;
    }
}
